@@ -29,7 +29,6 @@
 #include "weather-presets.h"
 #include "weather-home.h"
 #include "weather-utils.h"
-#include <values.h>
 /*******************************************************************************/
 void
 composition_right_horizontal_day_button(WDB *new_day_button){
@@ -50,17 +49,17 @@ composition_right_horizontal_day_button(WDB *new_day_button){
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_RIGHT_HORIZONTAL_BACKGROUND);
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
-        gtk_layout_put((new_day_button->box), new_day_button->background, 0, 26);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 0, 26);
     if (new_day_button->icon_image)
-        gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+3, 0);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+3, 0);
     if (new_day_button->wind)
-        gtk_layout_put((new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
     if (new_day_button->wind_text)
-        gtk_layout_put((new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -102,9 +101,9 @@ composition_right_horizontal_day_button(WDB *new_day_button){
     }
 
     if (day)
-            gtk_layout_put((new_day_button->box), day, 0, 60+37+10);
+            gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0, 60+37+10);
     if (temperature)
-            gtk_layout_put((new_day_button->box), temperature, 0+2, 60+37+9+30);
+            gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+2, 60+37+9+30);
 
     gtk_widget_destroy(new_day_button->label);
 #ifdef DEBUGFUNCTIONCALL
@@ -132,17 +131,17 @@ composition_central_horizontal_day_button(WDB *new_day_button)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_MIDDLE_HORIZONTAL_BACKGROUND);
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
-        gtk_layout_put((new_day_button->box), new_day_button->background, 0, 26);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 0, 26);
     if (new_day_button->icon_image)
-        gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+3, 0);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+3, 0);
     if (new_day_button->wind)
-        gtk_layout_put((new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
     if (new_day_button->wind_text)
-        gtk_layout_put((new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -182,9 +181,9 @@ composition_central_horizontal_day_button(WDB *new_day_button)
     gtk_widget_set_size_request(temperature, 66, 60);
 
     if (day)
-            gtk_layout_put((new_day_button->box), day, 0, 60+37+10);
+            gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0, 60+37+10);
     if (temperature)
-            gtk_layout_put((new_day_button->box), temperature, 0+2, 60+37+9+30);
+            gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+2, 60+37+9+30);
 
     gtk_widget_destroy(new_day_button->label);
 #ifdef DEBUGFUNCTIONCALL
@@ -212,17 +211,17 @@ composition_central_vertical_day_button(WDB *new_day_button)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_LEFT_VERTICAL_BACKGROUND);
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 200);
     if (new_day_button->background)
-        gtk_layout_put((new_day_button->box), new_day_button->background, 0, 0);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 0, 0);
     if (new_day_button->icon_image)
-        gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+3, 2);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+3, 2);
     if (new_day_button->wind)
-        gtk_layout_put((new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
     if (new_day_button->wind_text)
-        gtk_layout_put((new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -262,9 +261,9 @@ composition_central_vertical_day_button(WDB *new_day_button)
     gtk_widget_set_size_request(temperature, 66, 60);
 
     if (day)
-            gtk_layout_put((new_day_button->box), day, 0, 60+37+17-2);
+            gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0, 60+37+17-2);
     if (temperature)
-            gtk_layout_put((new_day_button->box), temperature, 0+2, 60+37+16+30-5 );
+            gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+2, 60+37+16+30-5 );
 
     gtk_widget_destroy(new_day_button->label);
 #ifdef DEBUGFUNCTIONCALL
@@ -292,7 +291,7 @@ composition_left_vertical_day_button(WDB *new_day_button, gint layout)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_LEFT_VERTICAL_BACKGROUND);
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -335,33 +334,33 @@ composition_left_vertical_day_button(WDB *new_day_button, gint layout)
         case PRESET_NOW_PLUS_TWO:
             gtk_widget_set_size_request(new_day_button->box, 70, 200);
             if (new_day_button->background)
-                gtk_layout_put((new_day_button->box), new_day_button->background, 12+15-6, 0);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 12+15-6, 0);
             if (new_day_button->icon_image)
-                gtk_layout_put((new_day_button->box), new_day_button->icon_image, 12+15-6+3, 2);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 12+15-6+3, 2);
             if (new_day_button->wind)
-                gtk_layout_put((new_day_button->box), new_day_button->wind, 12+15-10+14, 66-4);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 12+15-10+14, 66-4);
             if (new_day_button->wind_text)
-                gtk_layout_put((new_day_button->box), new_day_button->wind_text, 12+15-6+14+6, 66+5);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 12+15-6+14+6, 66+5);
             if (day)
-                    gtk_layout_put((new_day_button->box), day, 12+15, 60+37+17-2);
+                    gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 12+15, 60+37+17-2);
             if (temperature)
-                    gtk_layout_put((new_day_button->box), temperature, 12+15+2, 60+37+16+30-5);
+                    gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 12+15+2, 60+37+16+30-5);
             break;
         default:
         case PRESET_NOW_PLUS_THREE_V:
             gtk_widget_set_size_request(new_day_button->box, 70, 200);
             if (new_day_button->background)
-                gtk_layout_put((new_day_button->box), new_day_button->background, 0, 0);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 0, 0);
             if (new_day_button->icon_image)
-                gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+3, 2);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+3, 2);
             if (new_day_button->wind)
-                gtk_layout_put((new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
             if (new_day_button->wind_text)
-                gtk_layout_put((new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5);
             if (day)
-                    gtk_layout_put((new_day_button->box), day, 0, 60+37+17-2);
+                    gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0, 60+37+17-2);
             if (temperature)
-                    gtk_layout_put((new_day_button->box), temperature, 0+2, 60+37+16+30-5);
+                    gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+2, 60+37+16+30-5);
             break;
     }
 
@@ -388,7 +387,7 @@ composition_right_vertical_day_button(WDB *new_day_button, gint layout)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_RIGHT_VERTICAL_BACKGROUND);
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -431,32 +430,32 @@ composition_right_vertical_day_button(WDB *new_day_button, gint layout)
     switch (layout){
         case PRESET_NOW_PLUS_TWO:
             if (new_day_button->background)
-                gtk_layout_put((new_day_button->box), new_day_button->background, 7, 0);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 7, 0);
             if (new_day_button->icon_image)
-                gtk_layout_put((new_day_button->box), new_day_button->icon_image, 7+3, 2);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 7+3, 2);
             if (new_day_button->wind)
-                gtk_layout_put((new_day_button->box), new_day_button->wind, 7-5+14, 66-4);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 7-5+14, 66-4);
             if (new_day_button->wind_text)
-                gtk_layout_put((new_day_button->box), new_day_button->wind_text, 7+14+6, 66+5); 
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 7+14+6, 66+5); 
             if (day)
-                gtk_layout_put((new_day_button->box), day, 0+8, 60+37+17-2);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0+8, 60+37+17-2);
             if (temperature)
-                gtk_layout_put((new_day_button->box), temperature, 0+8+2, 60+37+16+30-5);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+8+2, 60+37+16+30-5);
             break;
         default:
         case PRESET_NOW_PLUS_THREE_V:
             if (new_day_button->background)
-                gtk_layout_put((new_day_button->box), new_day_button->background, 0, 0);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 0, 0);
             if (new_day_button->icon_image)
-                gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+3, 2);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+3, 2);
             if (new_day_button->wind)
-                gtk_layout_put((new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
             if (new_day_button->wind_text)
-                gtk_layout_put((new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5); 
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5); 
             if (day)
-                gtk_layout_put((new_day_button->box), day, 0+1, 60+37+17-2);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0+1, 60+37+17-2);
             if (temperature)
-                gtk_layout_put((new_day_button->box), temperature, 0+1+2, 60+37+16+30-5);
+                gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+1+2, 60+37+16+30-5);
             break;
     }
 
@@ -506,61 +505,25 @@ composition_now(WDB *new_day_button, gint layout)
             gtk_widget_set_size_request(new_day_button->box, xoffset+140+1, 37+15+106);
             break;
     }
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 /* Packing all to the box */
     if (new_day_button->background)
-//        gtk_layout_put((new_day_button->box), new_day_button->background, xoffset, 37+15);
-        gtk_layout_put((new_day_button->box), new_day_button->background, xoffset, 37+15);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, xoffset, 37+15);
     if (new_day_button->icon_image)
- //       gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+image_xoffset, 0);
-        gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+image_xoffset, 0);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+image_xoffset, 0);
     if (new_day_button->wind)
-    //    gtk_layout_put((new_day_button->box), new_day_button->wind, (87+14) + xoffset + wind_xoffset - 11, 5+37+10);
-        gtk_layout_put((new_day_button->box), new_day_button->wind, (87+14) + xoffset + wind_xoffset - 11, 5+37+10);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, (87+14) + xoffset + wind_xoffset - 11, 5+37+10);
     if (new_day_button->wind_text)
-  //      gtk_layout_put((new_day_button->box), new_day_button->wind_text, (87+14) + xoffset + wind_xoffset, 7+37+18+1);
-        gtk_layout_put((new_day_button->box), new_day_button->wind_text, (87+14) + xoffset + wind_xoffset, 7+37+18+1);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, (87+14) + xoffset + wind_xoffset, 7+37+18+1);
     if (new_day_button->shadow_label)
-      //  gtk_layout_put((new_day_button->box), new_day_button->shadow_label, xoffset+2, 60+37+15+2);
-        gtk_layout_put((new_day_button->box), new_day_button->shadow_label, xoffset+2, 60+37+15+2);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->shadow_label, xoffset+2, 60+37+15+2);
     if (new_day_button->label)
-      //  gtk_layout_put((new_day_button->box), new_day_button->label, xoffset, 60+37+15);
-        gtk_layout_put((new_day_button->box), new_day_button->label, xoffset, 60+37+15);
+        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->label, xoffset, 60+37+15);
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
  
 }
-/*******************************************************************************/
-void
-realize (GtkWidget *widget)
-{
-    GdkPixmap *background;
-    GdkPixbuf *pixbuf;
-    GdkPixbuf *scaled;
-    GdkColormap *colormap;
-    GError *error=NULL;
-    GtkStyle *style;
-    gboolean boolit;
-    GdkScreen *screen;
-
-    return;
-    screen = gtk_widget_get_screen (widget);
-    colormap = gdk_screen_get_rgba_colormap (screen);
-    gtk_widget_set_colormap (widget, colormap);
-    pixbuf=gdk_pixbuf_new_from_file("/usr/share/omweather/button_icons/nothing.png",&error);
-    scaled=gdk_pixbuf_scale_simple(pixbuf,700,700, GDK_INTERP_BILINEAR);
-    g_object_unref(G_OBJECT(pixbuf));
-//    scaled=gdk_pixbuf_new_from_file("/usr/share/omweather/button_icons/nothing.png",&error);
-    gdk_pixbuf_render_pixmap_and_mask_for_colormap(scaled,colormap,&background,NULL,0);
-    g_object_unref(G_OBJECT(scaled));
-    style = gtk_style_new();
-    style->bg_pixmap[0] = background;
-    gtk_widget_set_style(GTK_WIDGET(widget),GTK_STYLE(style));
-    g_object_unref (G_OBJECT (style));
-
-}
-   
 /*******************************************************************************/
 GtkWidget *
 next_station_preset_now(gint layout)
@@ -574,54 +537,43 @@ next_station_preset_now(gint layout)
     gchar           buffer[2048];
     gint            x_width = 0;
     gint            x_offset = 0;
-
-
-    GdkPixmap *background;
-
-//#ifdef DEBUGFUNCTIONCALL
+#ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
-//#endif
-    //widget = gtk_fixed_new();
-    widget = gtk_layout_new(NULL, NULL);
-    gtk_widget_set_size_request(widget, 168, 74);
-    realize(widget);
+#endif
+    widget = gtk_fixed_new();
     memset(buffer, 0, sizeof(buffer));
     switch (layout){
         case PRESET_NOW_PLUS_THREE_H:
         case PRESET_NOW_PLUS_SEVEN:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_HORIZONTAL);
-//            background_town = gtk_image_new_from_file (buffer);
+            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-     //           gtk_layout_put((widget), background_town, 12+15, 0);
-                gtk_layout_put((widget), background_town, 12+15, 0);
+                gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
             x_width = 138;
             x_offset = 12+15;
             break; 
         case PRESET_NOW_PLUS_TWO:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_TWO);
-//            background_town = gtk_image_new_from_file (buffer);
+            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-         //       gtk_layout_put((widget), background_town, 12+15, 0);
-                gtk_layout_put((widget), background_town, 12+15, 0);
+                gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
             x_width = 140;
             x_offset = 12+15;
             break;
         case PRESET_NOW_PLUS_THREE_V:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_THREE_V);
-//            background_town = gtk_image_new_from_file (buffer);
+            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-//                gtk_layout_put((widget), background_town, 0, 0);
-                gtk_layout_put((widget), background_town, 0, 0);
+                gtk_fixed_put(GTK_FIXED(widget), background_town, 0, 0);
             x_width = 210;
             x_offset = 0;
             break;
         default:
         case PRESET_NOW:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN);
-//            background_town = gtk_image_new_from_file (buffer);
+            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-//                gtk_layout_put((widget), background_town, 12+15, 0);
-                gtk_layout_put((widget), background_town, 12+15, 0);
+                gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
             x_width = 140;
             x_offset = 12+15;
             break;
@@ -664,19 +616,14 @@ next_station_preset_now(gint layout)
     }
 
     if (station_name_btn)
-//        gtk_layout_put((widget), station_name_btn, x_offset, 0);
-        gtk_layout_put((widget), station_name_btn, x_offset, 0);
-    gtk_widget_show(station_name_btn);
+        gtk_fixed_put(GTK_FIXED(widget), station_name_btn, x_offset, 0);
     if (shadow_station_text)
-//        gtk_layout_put((widget), shadow_station_text, x_offset+2+1, 17+1);
-        gtk_layout_put((widget), shadow_station_text, x_offset+2+1, 17+1);
+        gtk_fixed_put(GTK_FIXED(widget), shadow_station_text, x_offset+2+1, 17+1);
     if (station_text)
-//        gtk_layout_put((widget), station_text, x_offset+1+1,17);
-        gtk_layout_put((widget), station_text, x_offset+1+1,17);
+        gtk_fixed_put(GTK_FIXED(widget), station_text, x_offset+1+1,17);
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
-   gtk_widget_show_all(widget);
     return widget;
 }
 
@@ -689,9 +636,9 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
     gchar       buffer[2048];
     GdkPixbuf   *icon_buffer;
     gchar       *begin_of_string;
-//#ifdef DEBUGFUNCTIONCALL
+#ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
-//#endif
+#endif
     /* create day label */
     new_day_button->label = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(new_day_button->label), text);
@@ -716,7 +663,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
     /* Set font size for label */
     set_font(new_day_button->wind_text, PRESET_WIND_FONT, -1);
     gtk_widget_set_size_request(new_day_button->wind_text, 30, 30);
-#if 0
+
    /* create day icon buffer */
     icon_buffer =
           gdk_pixbuf_new_from_file_at_size(icon,
@@ -728,7 +675,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
         new_day_button->icon_image = create_icon_widget(icon_buffer, icon, PRESET_NORMAL_IMAGE_SIZE, &app->clutter_objects_in_main_form);
     else
         new_day_button->icon_image = NULL;
-#endif
+
     memset(buffer, 0, sizeof(buffer));
     switch (wind_direction){
        case TO_SOUTH:
@@ -776,7 +723,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
            begin_of_string = strstr(buffer,".png"); 
            snprintf(begin_of_string, sizeof(buffer) - strlen(buffer) - 1, "%s","_warning.png");
         }
-#if 0
+
         /* create day icon buffer */
         icon_buffer =
           gdk_pixbuf_new_from_file(buffer,
@@ -788,15 +735,11 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
         }
         else
             new_day_button->wind = NULL;
-#endif
     }
-  //  new_day_button->box  = gtk_fixed_new();
-    new_day_button->box  = gtk_layout_new(NULL, NULL);
-    realize(new_day_button->box);
-    gtk_widget_set_size_request(new_day_button->box, 1, 4);
-//#ifdef DEBUGFUNCTIONCALL
+    new_day_button->box  = gtk_fixed_new();
+#ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
-//#endif
+#endif
 }
 /**********************************************************************************************/
 void
@@ -807,9 +750,9 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
     gchar       buffer[2048];
     GdkPixbuf   *icon_buffer;
     gchar       *begin_of_string;
-//#ifdef DEBUGFUNCTIONCALL
+#ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
-//#endif
+#endif
     /* create day label */
     new_day_button->label = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(new_day_button->label), text);
@@ -853,7 +796,6 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
     set_font(new_day_button->wind_text, PRESET_WIND_FONT, -1);
     gtk_widget_set_size_request(new_day_button->wind_text, 30, 30);
 
-#if 0
    /* create day icon buffer */
     icon_buffer =
           gdk_pixbuf_new_from_file_at_size(icon,
@@ -866,7 +808,7 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
 //        new_day_button->icon_image = create_icon_widget(icon_buffer, icon, icon_size, NULL);
     else
         new_day_button->icon_image = NULL;
-#endif
+
     memset(buffer, 0, sizeof(buffer));
     switch (wind_direction){
        case TO_SOUTH:
@@ -908,18 +850,14 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
                     wind_speed = wind_speed * 1.6;
                     break;
         }
-	/*
         if (wind_speed < STRONG_WIND)
-//            new_day_button->wind = gtk_image_new_from_file (buffer);
+            new_day_button->wind = gtk_image_new_from_file (buffer);
         else{
            begin_of_string = strstr(buffer,".png"); 
            snprintf(begin_of_string, sizeof(buffer) - strlen(buffer) - 1, "%s","_warning.png");
-//           new_day_button->wind = gtk_image_new_from_file (buffer);
+           new_day_button->wind = gtk_image_new_from_file (buffer);
         }
-	*/
     }
- //   new_day_button->box  = gtk_fixed_new();
-    new_day_button->box  = gtk_layout_new(NULL, NULL);
-    realize(new_day_button->box);
+    new_day_button->box  = gtk_fixed_new();
 }
 /*******************************************************************************/
